@@ -1,3 +1,4 @@
+import hashlib
 import unittest
 
 from httpretty import HTTPretty
@@ -5,9 +6,14 @@ from httpretty import HTTPretty
 from m2x.client import M2XClient
 
 
+API_KEY = hashlib.md5('python-m2x'.encode('utf8')).hexdigest()
+
+
 class TestCase(unittest.TestCase):
+    API_VERSION = None
+
     def setUp(self):
-        self.client = M2XClient(key='foobar', endpoint='http://foobar.com')
+        self.client = M2XClient(key=API_KEY, api=self.API_VERSION)
         HTTPretty.enable()
 
     def tearDown(self):
